# -*- coding: utf-8 -*-
import time
from odoo import models
from odoo.http import request
from odoo.addons.saas_worker.const import WEBSITE

UPDATE_LAST_CNX_EVERY = 3600


class Http(models.AbstractModel):
    """
    Augment ir.http to update the last connection date when the session is loaded.
    """

    _inherit = "ir.http"

    def session_info(self):
        """
        Update last connection date in meta, unless that has been done recently.
        Adjust the expiration date if appropriate for this database mode.
        """
        result = super(Http, self).session_info()

        # Add env related odoo.com website url (for redirecting user.)
        result["odoo_website_url"] = WEBSITE

        if not self.env.user.has_group("base.group_user"):
            return result
        last_cnx = request.session.get("last_cnx_updated")
        if not last_cnx or last_cnx < time.time() - UPDATE_LAST_CNX_EVERY:
            self.env["res.users"].update_cnx_date(self.env.registry.db_name, self.env.user.id)
            request.session["last_cnx_updated"] = time.time()
        return result

    @classmethod
    def _get_translation_frontend_modules_name(cls):
        mods = super()._get_translation_frontend_modules_name()
        return mods + ['saas_trial']
